@@ -147,24 +147,19 @@ def create_worker_pool_from_json(wp_json_file: str) -> None:
                     },
                 ],
             ),
-            ("maxNodes", CONFIG_WP.max_nodes),
-            ("minNodes", CONFIG_WP.min_nodes),
-            (
-                "createNodeWorkers",
-                {"targetCount": CONFIG_WP.workers_per_vcpu, "targetType": "PER_VCPU"}
-                if CONFIG_WP.workers_per_vcpu
-                else {
-                    "targetCount": CONFIG_WP.workers_per_node,
-                    "targetType": "PER_NODE",
-                },
-            ),
             ("workerTag", CONFIG_WP.worker_tag),
             ("nodeBootTimeLimit", f"PT{CONFIG_WP.node_boot_time_limit}M"),
             ("nodeIdleGracePeriod", f"PT{CONFIG_WP.node_idle_grace_period}M"),
             ("nodeIdleTimeLimit", f"PT{CONFIG_WP.node_idle_time_limit}M"),
         ]:
             if provisioned_properties.get(key) is None and value is not None:
-                print_log(f"Setting 'provisionedProperties.{key}': '{value}'")
+                if key == "autoShutdownConditions":
+                    for condition in value:
+                        print_log(
+                            f"Setting '{condition['type']}': '{condition['delay']}'"
+                        )
+                else:
+                    print_log(f"Setting 'provisionedProperties.{key}': '{value}'")
                 provisioned_properties[key] = value
 
     except KeyError as e:
