@@ -37,6 +37,7 @@ from yd_commands.config import (
     generate_id,
     link_entity,
     load_config_work_requirement,
+    update_config_work_requirement,
 )
 from yd_commands.config_keys import *
 from yd_commands.csv_data import (
@@ -47,11 +48,11 @@ from yd_commands.csv_data import (
 )
 from yd_commands.interactive import confirmed
 from yd_commands.mustache import (
-    TASK_COUNT,
-    TASK_GROUP_COUNT,
-    TASK_GROUP_NUMBER,
-    TASK_NUMBER,
-    WR_NAME,
+    L_TASK_COUNT,
+    L_TASK_GROUP_COUNT,
+    L_TASK_GROUP_NUMBER,
+    L_TASK_NUMBER,
+    L_WR_NAME,
     add_substitutions,
     load_json_file_with_mustache_substitutions,
     load_jsonnet_file_with_mustache_substitutions,
@@ -206,13 +207,14 @@ def submit_work_requirement(
             wr_data[TASK_TYPES] = [wr_data[TASK_TYPE]]
 
     # Overwrite the WR name?
-    global ID
+    global ID, CONFIG_WR
     ID = format_yd_name(
-        wr_data.get(WR_NAME, ID if CONFIG_WR.wr_name is None else CONFIG_WR.wr_name)
+        wr_data.get(L_WR_NAME, ID if CONFIG_WR.wr_name is None else CONFIG_WR.wr_name)
     )
     # Lazy substitution of the Work Requirement name, now it's defined
-    add_substitutions(subs={WR_NAME: ID})
+    add_substitutions(subs={L_WR_NAME: ID})
     process_mustache_substitutions(wr_data)
+    CONFIG_WR = update_config_work_requirement(CONFIG_WR)
 
     # Handle any files that need to be uploaded
     global UPLOADED_FILES
@@ -443,12 +445,10 @@ def add_tasks_to_task_group(
         wr_data[TASK_GROUPS][tg_number][TASKS] = [{}]
         num_tasks = 1
 
-    # If 'taskCount' is set at the Json Work Requirement or
-    # Task Group levels, and there is only one Task, create 'taskCount'
-    # copies of the Task. Note: NOT inherited from the TOML level.
-    task_group_task_count = wr_data[TASK_GROUPS][tg_number].get(
-        TASK_COUNT, wr_data.get(TASK_COUNT, None)
-    )
+    # If 'taskCount' is set at the Task Group level, and there is only one Task,
+    # create 'taskCount' copies of the Task.
+    # Note: NOT inherited from the TOML or WR levels.
+    task_group_task_count = wr_data[TASK_GROUPS][tg_number].get(TASK_COUNT, None)
     if task_group_task_count is not None:
         if num_tasks == 1:
             task_count = check_int(task_group_task_count)
@@ -536,10 +536,10 @@ def add_tasks_to_task_group(
             )
             optional_inputs_list = check_list(
                 task.get(
-                    OPTIONAL_INPUTS,
+                    INPUTS_OPTIONAL,
                     task_group_data.get(
-                        OPTIONAL_INPUTS,
-                        wr_data.get(OPTIONAL_INPUTS, CONFIG_WR.optional_inputs),
+                        INPUTS_OPTIONAL,
+                        wr_data.get(INPUTS_OPTIONAL, CONFIG_WR.optional_inputs),
                     ),
                 )
             )
@@ -697,9 +697,12 @@ def add_tasks_to_task_group(
         tasks_list.clear()
 
     if not ARGS_PARSER.dry_run:
-        print_log(
-            f"Added a total of {num_tasks} Task(s) to Task Group '{task_group.name}'"
-        )
+        if num_tasks > 0:
+            print_log(
+                f"Added a total of {num_tasks} Task(s) to Task Group '{task_group.name}'"
+            )
+        else:
+            print_log(f"No Tasks added to Task Group '{task_group.name}'")
 
 
 def get_task_data_property(
@@ -813,19 +816,19 @@ def get_task_name(
 
     if name:
         name = name.replace(
-            f"{{{{{TASK_NUMBER}}}}}",
+            f"{{{{{L_TASK_NUMBER}}}}}",
             formatted_number_str(task_number, num_tasks),
         )
         name = name.replace(
-            f"{{{{{TASK_COUNT}}}}}",
+            f"{{{{{L_TASK_COUNT}}}}}",
             str(num_tasks),
         )
         name = name.replace(
-            f"{{{{{TASK_GROUP_NUMBER}}}}}",
+            f"{{{{{L_TASK_GROUP_NUMBER}}}}}",
             formatted_number_str(task_group_number, num_task_groups),
         )
         name = name.replace(
-            f"{{{{{TASK_GROUP_COUNT}}}}}",
+            f"{{{{{L_TASK_GROUP_COUNT}}}}}",
             str(num_task_groups),
         )
 
@@ -848,15 +851,15 @@ def get_task_group_name(
 
     if name:
         name = name.replace(
-            f"{{{{{TASK_GROUP_NUMBER}}}}}",
+            f"{{{{{L_TASK_GROUP_NUMBER}}}}}",
             formatted_number_str(task_group_number, num_task_groups),
         )
         name = name.replace(
-            f"{{{{{TASK_GROUP_COUNT}}}}}",
+            f"{{{{{L_TASK_GROUP_COUNT}}}}}",
             str(num_task_groups),
         )
         name = name.replace(
-            f"{{{{{TASK_COUNT}}}}}",
+            f"{{{{{L_TASK_COUNT}}}}}",
             str(task_count),
         )
 
@@ -1034,7 +1037,7 @@ def submit_json_raw(wr_file: str):
     # Lazy substitution of Work Requirement name
     wr_data["name"] = format_yd_name(wr_data["name"])
     wr_name = wr_data["name"]
-    add_substitutions(subs={WR_NAME: wr_name})
+    add_substitutions(subs={L_WR_NAME: wr_name})
     process_mustache_substitutions(wr_data)
 
     if ARGS_PARSER.dry_run:
